"""Copyright 2009 Ben Delaney"""


FULLSCREEN = False  ##Change to False to start in windowed mode.


import pygame, random
import labels, plants
pygame.init()

groundLevel = 440
gamesprites = pygame.sprite.Group()
flowers = pygame.sprite.Group()
bugs = pygame.sprite.Group()

class player(pygame.sprite.Sprite):
    def __init__(self):
        pygame.sprite.Sprite.__init__(self)
        self.image_right = pygame.image.load("data/Bugman_right.png")
        self.image_right.convert_alpha()
        self.image_left = pygame.image.load("data/Bugman_left.png")
        self.image_left.convert_alpha()
        self.rect = self.image_right.get_rect()
        self.lives = 5
        self.score = 0
        self.reset()
        

    
    def reset(self):
        self.rect.center = (200, 200)
        self.dx = 0
        self.dy = 0
        self.scroll = 0
        self.health = 100
        self.image = self.image_right


    def checkkeys(self):
        keys = pygame.key.get_pressed()
        if keys[pygame.K_RIGHT]:
            self.image = self.image_right
            if self.rect.bottom == groundLevel:
                self.dx = 5
            else:
                if self.dx < 5:
                    self.dx += 0.25

        elif keys [pygame.K_LEFT]:
            self.image = self.image_left
            if self.rect.bottom == groundLevel:
                self.dx = -5
            else:
                if self.dx > -5:
                    self.dx -= 0.25

        else:
            if self.rect.bottom == groundLevel:
                self.dx = 0

        if keys [pygame.K_SPACE]:
            if self.rect.bottom == groundLevel:
                self.dy = -12 ## Jump velocity value
            self.gravity_value = 0.25
        else:
            self.gravity_value = 0.5
    

    def gravity(self):
        if self.rect.bottom != groundLevel or self.dy != 0:
            self.dy += self.gravity_value ##Gravity value

            self.rect.centery += self.dy

            if self.rect.bottom > groundLevel:
                self.rect.bottom = groundLevel
                self.dy = 0

    def movex(self):

        self.rect.centerx += self.dx
        
        if self.rect.centerx >= 490:
            difference = 490 - self.rect.centerx
            self.scroll += difference
            if self.scroll < self.scrolllimit:
                self.scroll = self.scrolllimit
                if self.rect.right > 640:
                    self.rect.right = 640
            else:
                self.rect.centerx = 490

        elif self.rect.centerx <= 150:
            difference = 150 - self.rect.centerx
            self.scroll += difference
            if self.scroll > 0:
                self.scroll = 0
                if self.rect.left < 0:
                    self.rect.left = 0
            else:
                self.rect.centerx = 150

    def checkhealth(self):
        if self.health < 0:
            self.lives -= 1
            self.reset()

    def update(self):
        self.checkkeys()
        self.gravity()
        self.movex()
        self.checkhealth()

def loadlevel():
    level = pygame.image.load("data/Testlevel.bmp")
    level = level.convert()
    return level

def createplant(weed_r, flower_r, groundlevel):
    if not random.randrange(weed_r):
        print"weed"
        x = random.randrange(Levelwidth)
        plants.Weed(x, Bugman, gamesprites, flowers, groundlevel)
    if not random.randrange(flower_r):
        print "flower"
        Bugman.score += 50
        x = random.randrange(Levelwidth)
        plants.Flower(x, Bugman, (gamesprites, flowers), groundlevel)


def instructions():
    print"""
Weedie

You are Weedie, A tiny round man who lives
down with the flowers.

Instructions:
Use the left & right arrow keys to move and the
spacebar to jump, (the longer you hold it down
the higher you will jump). You score whenever
flowers grow or you squash bugs by landing on
them. Avoid the weeds!
"""
    a = raw_input("Press enter to play!")
    main()


def score():
    print "Your score was:", Bugman.score
    print
    a = raw_input("Press enter to close.")
    


def main():
    ##Display
    if FULLSCREEN:
        screen = pygame.display.set_mode((640, 480), pygame.FULLSCREEN)
    else:
        screen = pygame.display.set_mode((640, 480))

    pygame.mouse.set_visible(False)

    ##Load
    background = loadlevel()
    mainFont = pygame.font.Font("data/you_are_what_you_eat_regular.ttf", 30)
    
    ##Objects

    global Bugman
    Bugman = player()
    gamesprites.add(Bugman)

    global Levelwidth
    Levelwidth = background.get_width()
    Bugman.scrolllimit = Levelwidth - 640
    Bugman.scrolllimit *= -1

    scoreboard = labels.Label("Score:", (25, 25), mainFont, (255, 255, 255))
    lifeboard = labels.Label("Lives:", (240, 25), mainFont, (255, 255, 255)) 
    healthlabel = labels.Label("Health", (395, 25), mainFont, (255, 255, 255))
    healthbar = labels.Bar(20, 100, (515, 37))

    overlay = pygame.sprite.Group(scoreboard, lifeboard, healthlabel, healthbar)


    theweed = plants.Weed(500, Bugman, gamesprites, groundLevel)

    ##Main Loop
    screen.blit(background, (0, 0))
    clock = pygame.time.Clock()
    keepgoing = True

    while keepgoing:
        clock.tick(30)
        
        
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                keepgoing = False

            elif event.type == pygame.KEYDOWN:
                if event.key == pygame.K_ESCAPE:
                    keepgoing = False
                    
        createplant(600, 600, groundLevel)

        scoreboard.text = "Score: %d" % Bugman.score
        lifeboard.text = "Lives: %d" % Bugman.lives
        healthbar.length = Bugman.health
        
        screen.blit(background, (Bugman.scroll, 0))
        gamesprites.update()
        gamesprites.draw(screen)

        overlay.update()
        overlay.draw(screen)
        
        if not Bugman.lives:
            keepgoing = false

        pygame.display.flip()

    pygame.mouse.set_visible(True)
    


if __name__ == "__main__":
    instructions()
